@@ -1,6 +1,8 @@
-pub extern crate capnp;
 #[macro_use]
-extern crate serde_derive;
+pub extern crate serde_derive;
+pub extern crate capnp;
+pub extern crate serde;
+pub extern crate serde_json;
 
 pub mod base64;
 pub mod prost;
